@@ -1,16 +1,6 @@
 test_that("read_gsheets import data from multiple sheets in Google Sheets", {
 
-  skip_if_no_token <- function() {
-    if (googlesheets4::gs4_has_token()) {
-      # hack to slow things down in CI
-      Sys.sleep(3)
-    } else {
-      skip("No token")
-    }
-  }
-
-  skip_if_no_token()
-  skip_if_offline()
+  googlesheets4::gs4_deauth()
 
   sheet_id <- "1izO0mHu3L9AMySQUXGDn9GPs1n-VwGFSEoAKGhqVQh0"
 
@@ -22,7 +12,6 @@ test_that("read_gsheets import data from multiple sheets in Google Sheets", {
 
   expect_equal(dim(test_data), dim(test_data))
 
-
 })
 
 
